@@ -696,7 +696,7 @@ class MieStratifiedSphere(MieScatterer):
     ):
         def coeffs(radius, refractive_index, refractive_index_medium, wavelength):
             assert np.all(
-                a[1:] >= a[:-1]
+                radius[1:] >= radius[:-1]
             ), "Radius of the shells of a stratified sphere should be monotonically increasing"
 
             def inner(L):
