@@ -1,6 +1,6 @@
 import sys
 
-sys.path.append("..")  # Adds the module to path
+sys.path.append(".")  # Adds the module to path
 
 import unittest
 
